MultiLongPressUpDetails class
Details for callbacks that use GestureMultiLongPressUpCallback.
See also:
- MultiLongPressGestureRecognizer.onMultiLongPressUp, which uses GestureMultiLongPressUpCallback.
- MultiLongPressMoveUpdateDetails, the details for GestureMultiLongPressMoveUpdateCallback.
- MultiLongPressDetails, the details for GestureMultiLongPressCallback.
Constructors
- MultiLongPressUpDetails({Offset globalPosition = Offset.zero, Offset? localPosition})
-
Creates the details for a GestureMultiLongPressUpCallback.
const
Properties
- globalPosition → Offset
-
The global position at which the pointer lifted from the screen.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localPosition → Offset
-
The local position at which the pointer contacted the screen.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited